RadarrCollection class

Annotations
  • @Freezed.new()

Constructors

RadarrCollection({required int id, String? title, String? cleanTitle, String? sortTitle, required int tmdbId, String? overview, required bool monitored, required int qualityProfileId, String? rootFolderPath, required bool searchOnAdd, required RadarrMovieStatus minimumAvailability, DateTime? lastInfoSync, List<RadarrMediaCover>? images, List<RadarrCollectionMetadata>? movies, DateTime? added})
const
factory
RadarrCollection.fromJson(Map<String, Object?> json)
factory

Properties

added DateTime?
no setterinherited
cleanTitle String?
no setterinherited
copyWith → $RadarrCollectionCopyWith<RadarrCollection>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
images List<RadarrMediaCover>?
no setterinherited
lastInfoSync DateTime?
no setterinherited
minimumAvailability RadarrMovieStatus
no setterinherited
monitored bool
no setterinherited
movies List<RadarrCollectionMetadata>?
no setterinherited
overview String?
no setterinherited
qualityProfileId int
no setterinherited
rootFolderPath String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchOnAdd bool
no setterinherited
sortTitle String?
no setterinherited
title String?
no setterinherited
tmdbId int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited