RadarrCommand class

Annotations
  • @Freezed.new()

Constructors

RadarrCommand({required int id, @JsonKey.new(unknownEnumValue: RadarrCommandName.unknown) RadarrCommandName? name, String? commandName, String? message, required RadarrCommandBody body, required RadarrCommandPriority priority, required RadarrCommandStatus status, required DateTime queued, DateTime? started, DateTime? ended, @DurationStringConverter.new() Duration? duration, String? exception, required RadarrCommandTrigger trigger, String? clientUserAgent, DateTime? stateChangeTime, required bool sendUpdatesToClient, required bool updateScheduledTask, DateTime? lastExecutionTime})
const
factory
RadarrCommand.fromJson(Map<String, Object?> json)
factory

Properties

body RadarrCommandBody
no setterinherited
clientUserAgent String?
no setterinherited
commandName String?
no setterinherited
copyWith → $RadarrCommandCopyWith<RadarrCommand>
no setterinherited
duration Duration?
no setterinherited
ended DateTime?
no setterinherited
exception String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
lastExecutionTime DateTime?
no setterinherited
message String?
no setterinherited
name RadarrCommandName?
no setterinherited
priority RadarrCommandPriority
no setterinherited
queued DateTime
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendUpdatesToClient bool
no setterinherited
started DateTime?
no setterinherited
stateChangeTime DateTime?
no setterinherited
status RadarrCommandStatus
no setterinherited
trigger RadarrCommandTrigger
no setterinherited
updateScheduledTask bool
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited