RadarrCommandName enum
Values
- applicationCheckUpdate → const RadarrCommandName
-
const RadarrCommandName('ApplicationCheckUpdate') - applicationUpdate → const RadarrCommandName
-
const RadarrCommandName('ApplicationUpdate') - backup → const RadarrCommandName
-
const RadarrCommandName('Backup') - checkHealth → const RadarrCommandName
-
const RadarrCommandName('CheckHealth') - cleanUpRecycleBin → const RadarrCommandName
-
const RadarrCommandName('CleanUpRecycleBin') - clearBlocklist → const RadarrCommandName
-
const RadarrCommandName('ClearBlocklist') - clearLog → const RadarrCommandName
-
const RadarrCommandName('ClearLog') - cutoffUnmetMoviesSearch → const RadarrCommandName
-
const RadarrCommandName('CutoffUnmetMoviesSearch') - deleteLogFiles → const RadarrCommandName
-
const RadarrCommandName('DeleteLogFiles') - deleteUpdateLogFiles → const RadarrCommandName
-
const RadarrCommandName('DeleteUpdateLogFiles') - downloadedMoviesScan → const RadarrCommandName
-
const RadarrCommandName('DownloadedMoviesScan') - housekeeping → const RadarrCommandName
-
const RadarrCommandName('Housekeeping') - importListSync → const RadarrCommandName
-
const RadarrCommandName('ImportListSync') - manualImport → const RadarrCommandName
-
const RadarrCommandName('ManualImport') - messagingCleanup → const RadarrCommandName
-
const RadarrCommandName('MessagingCleanup') - missingMoviesSearch → const RadarrCommandName
-
const RadarrCommandName('MissingMoviesSearch') - moveMovie → const RadarrCommandName
-
const RadarrCommandName('MoveMovie') - moviesSearch → const RadarrCommandName
-
const RadarrCommandName('MoviesSearch') - processMonitoredDownloads → const RadarrCommandName
-
const RadarrCommandName('ProcessMonitoredDownloads') - refreshCollections → const RadarrCommandName
-
const RadarrCommandName('RefreshCollections') - refreshMonitoredDownloads → const RadarrCommandName
-
const RadarrCommandName('RefreshMonitoredDownloads') - refreshMovie → const RadarrCommandName
-
const RadarrCommandName('RefreshMovie') - renameFiles → const RadarrCommandName
-
const RadarrCommandName('RenameFiles') - renameMovie → const RadarrCommandName
-
const RadarrCommandName('RenameMovie') - resetApiKey → const RadarrCommandName
-
const RadarrCommandName('ResetApiKey') - resetQualityDefinitions → const RadarrCommandName
-
const RadarrCommandName('ResetQualityDefinitions') - rssSync → const RadarrCommandName
-
const RadarrCommandName('RssSync') - unknown → const RadarrCommandName
-
const RadarrCommandName('unknown')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RadarrCommandName> - A constant List of the values in this enum, in order of their declaration.