RadarrCustomFormatSpecification class

Annotations
  • @Freezed.new()

Constructors

RadarrCustomFormatSpecification({int? id, String? name, String? implementation, String? implementationName, String? infoLink, required bool negate, required bool required, List<RadarrField>? fields, List<RadarrCustomFormatSpecification>? presets})
const
factory
RadarrCustomFormatSpecification.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $RadarrCustomFormatSpecificationCopyWith<RadarrCustomFormatSpecification>
no setterinherited
fields List<RadarrField>?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int?
no setterinherited
implementation String?
no setterinherited
implementationName String?
no setterinherited
no setterinherited
name String?
no setterinherited
negate bool
no setterinherited
presets List<RadarrCustomFormatSpecification>?
no setterinherited
required bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited