RadarrDelayProfile class

Annotations
  • @Freezed.new()

Constructors

RadarrDelayProfile({int? id, required bool enableUsenet, required bool enableTorrent, required RadarrDownloadProtocol preferredProtocol, required int usenetDelay, required int torrentDelay, required bool bypassIfHighestQuality, required int order, required List<int> tags})
const
factory
RadarrDelayProfile.fromJson(Map<String, Object?> json)
factory

Properties

bypassIfHighestQuality bool
no setterinherited
copyWith → $RadarrDelayProfileCopyWith<RadarrDelayProfile>
no setterinherited
enableTorrent bool
no setterinherited
enableUsenet bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int?
no setterinherited
order int
no setterinherited
preferredProtocol RadarrDownloadProtocol
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
no setterinherited
torrentDelay int
no setterinherited
usenetDelay int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited