RadarrDownloadClientConfig class

Annotations
  • @Freezed.new()

Constructors

RadarrDownloadClientConfig({required int id, String? downloadClientWorkingFolders, required bool enableCompletedDownloadHandling, required int checkForFinishedDownloadInterval, required bool autoRedownloadFailed})
const
factory
RadarrDownloadClientConfig.fromJson(Map<String, Object?> json)
factory

Properties

autoRedownloadFailed bool
no setterinherited
checkForFinishedDownloadInterval int
no setterinherited
copyWith → $RadarrDownloadClientConfigCopyWith<RadarrDownloadClientConfig>
no setterinherited
downloadClientWorkingFolders String?
no setterinherited
enableCompletedDownloadHandling bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited