RadarrExtraFile class

Annotations
  • @Freezed.new()

Constructors

RadarrExtraFile({required int id, required int movieId, int? movieFileId, String? relativePath, String? extension, required RadarrExtraFileType type})
const
factory
RadarrExtraFile.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $RadarrExtraFileCopyWith<RadarrExtraFile>
no setterinherited
extension String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
movieFileId int?
no setterinherited
movieId int
no setterinherited
relativePath String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type RadarrExtraFileType
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited