RadarrField class

Annotations
  • @Freezed.new()

Constructors

RadarrField({required int order, String? name, String? label, String? unit, String? helpText, String? helpLink, dynamic value, String? type, required bool advanced, List<RadarrFieldSelectOption>? selectOptions, String? selectOptionsProviderAction, String? section, String? hidden, String? placeholder, int? id, String? implementation, String? implementationName, String? infoLink, bool? negate, bool? required})
const
factory
RadarrField.fromJson(Map<String, Object?> json)
factory

Properties

advanced bool
no setterinherited
copyWith → $RadarrFieldCopyWith<RadarrField>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
no setterinherited
helpText String?
no setterinherited
hidden String?
no setterinherited
id int?
no setterinherited
implementation String?
no setterinherited
implementationName String?
no setterinherited
no setterinherited
label String?
no setterinherited
name String?
no setterinherited
negate bool?
no setterinherited
order int
no setterinherited
placeholder String?
no setterinherited
required bool?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
section String?
no setterinherited
selectOptions List<RadarrFieldSelectOption>?
no setterinherited
selectOptionsProviderAction String?
no setterinherited
type String?
no setterinherited
unit String?
no setterinherited
value → dynamic
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited