RadarrHealth class

Annotations
  • @Freezed.new()

Constructors

RadarrHealth({int? id, String? source, required RadarrHealthType type, String? message, String? wikiUrl})
const
factory
RadarrHealth.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $RadarrHealthCopyWith<RadarrHealth>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int?
no setterinherited
message String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
no setterinherited
type RadarrHealthType
no setterinherited
wikiUrl String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited