RadarrHistory class

Annotations
  • @Freezed.new()

Constructors

RadarrHistory({required int id, required int movieId, String? sourceTitle, List<RadarrLanguage>? language, RadarrQualityModel? quality, List<RadarrCustomFormat>? customFormats, required bool qualityCutoffNotMet, required DateTime date, String? downloadId, required RadarrHistoryEventType eventType, required Map<String, String?> data, RadarrMovie? movie})
const
factory
RadarrHistory.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $RadarrHistoryCopyWith<RadarrHistory>
no setterinherited
customFormats List<RadarrCustomFormat>?
no setterinherited
data Map<String, String?>
no setterinherited
date DateTime
no setterinherited
downloadId String?
no setterinherited
eventType RadarrHistoryEventType
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
language List<RadarrLanguage>?
no setterinherited
movie RadarrMovie?
no setterinherited
movieId int
no setterinherited
quality RadarrQualityModel?
no setterinherited
qualityCutoffNotMet bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceTitle String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited