RadarrHostConfig class

Annotations
  • @Freezed.new()

Constructors

RadarrHostConfig({required int id, String? bindAddress, required int port, required int sslPort, required bool enableSsl, required bool launchBrowser, required RadarrAuthenticationType authenticationMethod, required bool analyticsEnabled, String? username, String? password, RadarrLogLevel? logLevel, String? consoleLogLevel, String? branch, String? apiKey, String? sslCertPath, String? sslCertPassword, String? urlBase, String? instanceName, String? applicationUrl, required bool updateAutomatically, required RadarrUpdateMechanism updateMechanism, String? updateScriptPath, required bool proxyEnabled, required RadarrProxyType proxyType, String? proxyHostname, required int proxyPort, String? proxyUsername, String? proxyPassword, String? proxyBypassFilter, required bool proxyBypassLocalAddresses, required RadarrCertificateValidation certificateValidation, String? backupFolder, required int backupInterval, required int backupRetention})
const
factory
RadarrHostConfig.fromJson(Map<String, Object?> json)
factory

Properties

analyticsEnabled bool
no setterinherited
apiKey String?
no setterinherited
applicationUrl String?
no setterinherited
authenticationMethod RadarrAuthenticationType
no setterinherited
backupFolder String?
no setterinherited
backupInterval int
no setterinherited
backupRetention int
no setterinherited
bindAddress String?
no setterinherited
branch String?
no setterinherited
certificateValidation RadarrCertificateValidation
no setterinherited
consoleLogLevel String?
no setterinherited
copyWith → $RadarrHostConfigCopyWith<RadarrHostConfig>
no setterinherited
enableSsl bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
instanceName String?
no setterinherited
launchBrowser bool
no setterinherited
logLevel RadarrLogLevel?
no setterinherited
password String?
no setterinherited
port int
no setterinherited
proxyBypassFilter String?
no setterinherited
proxyBypassLocalAddresses bool
no setterinherited
proxyEnabled bool
no setterinherited
proxyHostname String?
no setterinherited
proxyPassword String?
no setterinherited
proxyPort int
no setterinherited
proxyType RadarrProxyType
no setterinherited
proxyUsername String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sslCertPassword String?
no setterinherited
sslCertPath String?
no setterinherited
sslPort int
no setterinherited
updateAutomatically bool
no setterinherited
updateMechanism RadarrUpdateMechanism
no setterinherited
updateScriptPath String?
no setterinherited
urlBase String?
no setterinherited
username String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited