RadarrImportListConfig class
- Annotations
-
- @Freezed.new()
Constructors
- RadarrImportListConfig({required int id, required int importListSyncInterval, RadarrImportListCleanLevel? listSyncLevel, String? importExclusions})
-
constfactory
-
RadarrImportListConfig.fromJson(Map<
String, Object?> json) -
factory
Properties
-
copyWith
→ $RadarrImportListConfigCopyWith<
RadarrImportListConfig> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
no setterinherited
- importExclusions → String?
-
no setterinherited
- importListSyncInterval → int
-
no setterinherited
- listSyncLevel → RadarrImportListCleanLevel?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited