RadarrIndexerFlag class
- Annotations
-
- @Freezed.new()
Constructors
- RadarrIndexerFlag({required int id, String? name, String? nameLower})
-
constfactory
-
RadarrIndexerFlag.fromJson(Map<
String, Object?> json) -
factory
Properties
-
copyWith
→ $RadarrIndexerFlagCopyWith<
RadarrIndexerFlag> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
no setterinherited
- name → String?
-
no setterinherited
- nameLower → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited