RadarrMovieAlternateTitle class
- Annotations
-
- @Freezed.new()
Constructors
- RadarrMovieAlternateTitle({int? id, required RadarrTitleSource sourceType, required int movieMetadataId, String? title, String? cleanTitle, required int sourceId, required int votes, required int voteCount, required RadarrLanguage language})
-
constfactory
-
RadarrMovieAlternateTitle.fromJson(Map<
String, Object?> json) -
factory
Properties
- cleanTitle → String?
-
no setterinherited
-
copyWith
→ $RadarrMovieAlternateTitleCopyWith<
RadarrMovieAlternateTitle> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int?
-
no setterinherited
- language → RadarrLanguage
-
no setterinherited
- movieMetadataId → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceId → int
-
no setterinherited
- sourceType → RadarrTitleSource
-
no setterinherited
- title → String?
-
no setterinherited
- voteCount → int
-
no setterinherited
- votes → int
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited