RadarrQualityModel class

Annotations
  • @Freezed.new()

Constructors

RadarrQualityModel({required RadarrQuality quality, required RadarrQualityRevision revision, String? hardcodedSubs})
const
factory
RadarrQualityModel.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $RadarrQualityModelCopyWith<RadarrQualityModel>
no setterinherited
hardcodedSubs String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
quality RadarrQuality
no setterinherited
revision RadarrQualityRevision
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited