RadarrQualitySource enum
Values
- bluray → const RadarrQualitySource
-
const RadarrQualitySource('bluray') - cam → const RadarrQualitySource
-
const RadarrQualitySource('cam') - dvd → const RadarrQualitySource
-
const RadarrQualitySource('dvd') - telecine → const RadarrQualitySource
-
const RadarrQualitySource('telecine') - telesync → const RadarrQualitySource
-
const RadarrQualitySource('telesync') - tv → const RadarrQualitySource
-
const RadarrQualitySource('tv') - unknown → const RadarrQualitySource
-
const RadarrQualitySource('unknown') - webdl → const RadarrQualitySource
-
const RadarrQualitySource('webdl') - webrip → const RadarrQualitySource
-
const RadarrQualitySource('webrip') - workprint → const RadarrQualitySource
-
const RadarrQualitySource('workprint')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RadarrQualitySource> - A constant List of the values in this enum, in order of their declaration.