RadarrQueue class

Annotations
  • @Freezed.new()

Constructors

RadarrQueue({int? id, int? movieId, RadarrMovie? movie, required List<RadarrLanguage> languages, required RadarrQualityModel quality, required List<RadarrCustomFormat> customFormats, required double size, String? title, @JsonKey.new(name: 'sizeleft') required double sizeLeft, @JsonKey.new(name: 'timeleft') @DurationStringConverter.new() Duration? timeleft, DateTime? estimatedCompletionTime, @JsonKey.new(unknownEnumValue: RadarrQueueDownloadStatus.unknown) required RadarrQueueDownloadStatus status, required RadarrDownloadStatus trackedDownloadStatus, required RadarrDownloadState trackedDownloadState, required List<RadarrQueueTrackedDownloadStatus> statusMessages, String? errorMessage, String? downloadId, required RadarrDownloadProtocol protocol, String? downloadClient, String? indexer, String? outputPath})
const
factory
RadarrQueue.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $RadarrQueueCopyWith<RadarrQueue>
no setterinherited
customFormats List<RadarrCustomFormat>
no setterinherited
downloadClient String?
no setterinherited
downloadId String?
no setterinherited
errorMessage String?
no setterinherited
estimatedCompletionTime DateTime?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int?
no setterinherited
indexer String?
no setterinherited
languages List<RadarrLanguage>
no setterinherited
movie RadarrMovie?
no setterinherited
movieId int?
no setterinherited
outputPath String?
no setterinherited
protocol RadarrDownloadProtocol
no setterinherited
quality RadarrQualityModel
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
no setterinherited
sizeLeft double
no setterinherited
status RadarrQueueDownloadStatus
no setterinherited
statusMessages List<RadarrQueueTrackedDownloadStatus>
no setterinherited
timeleft Duration?
no setterinherited
title String?
no setterinherited
trackedDownloadState RadarrDownloadState
no setterinherited
trackedDownloadStatus RadarrDownloadStatus
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited