RadarrTagDetails class

Annotations
  • @Freezed.new()

Constructors

RadarrTagDetails({required int id, String? label, List<int>? delayProfileIds, List<int>? notificationIds, List<int>? restrictionIds, List<int>? importListIds, List<int>? movieIds, List<int>? indexerIds})
const
factory
RadarrTagDetails.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $RadarrTagDetailsCopyWith<RadarrTagDetails>
no setterinherited
delayProfileIds List<int>?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
importListIds List<int>?
no setterinherited
indexerIds List<int>?
no setterinherited
label String?
no setterinherited
movieIds List<int>?
no setterinherited
notificationIds List<int>?
no setterinherited
restrictionIds List<int>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited