RadarrExclusion class
- Annotations
-
- @Freezed.new()
Constructors
-
RadarrExclusion({int? id, String? name, List<
RadarrField> ? fields, List<RadarrExclusion> ? presets, String? implementationName, String? implementation, String? configContract, String? infoLink, RadarrProviderMessage? message, List<int> ? tags, required int tmdbId, String? movieTitle, required int movieYear}) -
constfactory
-
RadarrExclusion.fromJson(Map<
String, Object?> json) -
factory
Properties
- configContract → String?
-
no setterinherited
-
copyWith
→ $RadarrExclusionCopyWith<
RadarrExclusion> -
no setterinherited
-
fields
→ List<
RadarrField> ? -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int?
-
no setterinherited
- implementation → String?
-
no setterinherited
- implementationName → String?
-
no setterinherited
- infoLink → String?
-
no setterinherited
- message → RadarrProviderMessage?
-
no setterinherited
- movieTitle → String?
-
no setterinherited
- movieYear → int
-
no setterinherited
- name → String?
-
no setterinherited
-
presets
→ List<
RadarrExclusion> ? -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
no setterinherited
- tmdbId → int
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited