RadarrManualImportFile class
- Annotations
-
- @Freezed.new()
Constructors
-
RadarrManualImportFile({required String path, required String folderName, required int movieId, required String releaseGroup, required RadarrQualityModel quality, required List<
RadarrLanguage> languages}) -
constfactory
-
RadarrManualImportFile.fromJson(Map<
String, Object?> json) -
factory
Properties
-
copyWith
→ $RadarrManualImportFileCopyWith<
RadarrManualImportFile> -
no setterinherited
- folderName → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
languages
→ List<
RadarrLanguage> -
no setterinherited
- movieId → int
-
no setterinherited
- path → String
-
no setterinherited
- quality → RadarrQualityModel
-
no setterinherited
- releaseGroup → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited