RadarrMovieEditorOptions class
- Annotations
-
- @Freezed.new()
Constructors
-
RadarrMovieEditorOptions({required List<
int> movieIds, bool? monitored, int? qualityProfileId, RadarrMovieStatus? minimumAvailability, String? rootFolderPath, List<int> ? tags, RadarrApplyTagsMethod? applyTags, bool? moveFiles, bool? deleteFiles, bool? addImportExclusion}) -
constfactory
-
RadarrMovieEditorOptions.fromJson(Map<
String, Object?> json) -
factory
Properties
- addImportExclusion → bool?
-
no setterinherited
- applyTags → RadarrApplyTagsMethod?
-
no setterinherited
-
copyWith
→ $RadarrMovieEditorOptionsCopyWith<
RadarrMovieEditorOptions> -
no setterinherited
- deleteFiles → bool?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- minimumAvailability → RadarrMovieStatus?
-
no setterinherited
- monitored → bool?
-
no setterinherited
- moveFiles → bool?
-
no setterinherited
-
movieIds
→ List<
int> -
no setterinherited
- qualityProfileId → int?
-
no setterinherited
- rootFolderPath → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited