RadarrQualityProfile class
- Annotations
-
- @Freezed.new()
Constructors
-
RadarrQualityProfile({int? id, String? name, required bool upgradeAllowed, required int cutoff, required List<
RadarrQualityProfileItem> items, required int minFormatScore, required int cutoffFormatScore, required List<RadarrQualityProfileFormatItem> formatItems, required RadarrLanguage language}) -
constfactory
-
RadarrQualityProfile.fromJson(Map<
String, Object?> json) -
factory
Properties
-
copyWith
→ $RadarrQualityProfileCopyWith<
RadarrQualityProfile> -
no setterinherited
- cutoff → int
-
no setterinherited
- cutoffFormatScore → int
-
no setterinherited
-
formatItems
→ List<
RadarrQualityProfileFormatItem> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int?
-
no setterinherited
-
items
→ List<
RadarrQualityProfileItem> -
no setterinherited
- language → RadarrLanguage
-
no setterinherited
- minFormatScore → int
-
no setterinherited
- name → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- upgradeAllowed → bool
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited